{ nix-config, config, lib, pkgs, inputs, ... }:
{

  imports = with nix-config.homeModules; [
    shell-conf # shell, shell utils, cli tools, libs, tui's
  ];

  home = {
    packages = with pkgs; [
      cifs-utils
      plex
      beets
    ];

    username = "media";
    homeDirectory = "/home/media";

    sessionVariables = {
      NH_FLAKE = "\${HOME}/nixos-config";
    };


    home.stateVersion = "25.05";
  };

  programs = {
    home-manager.enable = true;

    password-store.enable = true;

    git = {
      enable = true;
      lfs = {
        enable = true;
      };
      userEmail = "matt@emenel.ca";
      userName = "Matt Nish-Lapidus";
      ignores = [
        ".DS_Store"
      ];
      extraConfig = {
        core = {
          editor = "$EDITOR";
          pager = "${pkgs.delta}/bin/delta";
        };
        interactive = {
          diffFilter = "${pkgs.delta}/bin/delta --color-only";
        };
        delta = {
          navigate = true;
          dark = true;
          line-numbers = true;
          side-by-side = true;
        };
        merge = {
          conflictstyle = "zdiff3";
        };
        init = {
          defaultBranch = "main";
        };
      };
      aliases = {
        co = "checkout";
        cm = "commit -m";
        aa = "add .";
        p = "push";
      };
    };
  };

  systemd.user = {
    enable = true;
    startServices = "sd-switch"; # auto reload services when home is rebuilt
  };
}
